@@ -1,7 +1,7 @@
 from dataclasses import dataclass
-from typing import List
-from typing import Union
 from enum import Enum
+from typing import Union
+from typing import List
 
 
 class ActivationsEnum(Enum):
@@ -205,12 +205,13 @@ class NodeType(Enum):
     GroundTruth = "GroundTruth"
     CustomLoss = "CustomLoss"
     Visualizer = "Visualizer"
-    TFOpLambda = "TFOpLambda"
     Lambda = "Lambda"
+    TFOpLambda = "TFOpLambda"
     SlicingOpLambda = "SlicingOpLambda"
     Repeat = "Repeat"
     Variable = "Variable"
     Gather = "Gather"
+    FixedDropout = "FixedDropout"
 
 
 @dataclass
@@ -1693,12 +1694,12 @@ class Visualizer:
 
 
 @dataclass
-class TFOpLambda:
+class Lambda:
     type: NodeType
 
 
 @dataclass
-class Lambda:
+class TFOpLambda:
     type: NodeType
 
 
@@ -1728,6 +1729,12 @@ class Gather:
     type: NodeType
 
 
+@dataclass
+class FixedDropout:
+    rate: float
+    type: NodeType
+
+
 @dataclass
 class NodeDataTypes:
     props: Union[Activation, ActivityRegularization, Add, AdditiveAttention, AlphaDropout, Average, AveragePooling1D, 
@@ -1748,5 +1755,5 @@ class NodeDataTypes:
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
                  SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxErf, OnnxHardSigmoid, 
-                 OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLoss, Visualizer, 
-                 TFOpLambda, Lambda, SlicingOpLambda, Repeat, Variable, Gather]
+                 OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLoss, Visualizer, Lambda, 
+                 TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
