@@ -125,7 +125,7 @@ class ModelParser:
         if self._should_transform_inputs:
             inputs_to_transpose = [k_input.name for k_input in k_model.inputs]
 
-        converted_k_model = convert_channels_first_to_last(k_model, inputs_to_transpose)
+        converted_k_model = convert_channels_first_to_last(k_model, inputs_to_transpose, self.custom_layers)
         model_schema = json.loads(converted_k_model.to_json())
         model_schema = replace_dots_in_model_schema(model_schema)
 
